Promus
======

.. image:: http://img.shields.io/pypi/dm/promus.svg
   :alt: Downloads
   :target: https://pypi.python.org/pypi/promus#downloads
.. image:: http://img.shields.io/pypi/v/promus.svg
   :alt: Latest Version
   :target: http://pypi.python.org/pypi/promus
.. image:: http://img.shields.io/badge/license-BSD-yellow.svg
   :alt: BSD License
   :target: http://opensource.org/licenses/BSD-3-Clause

Promus is a remote manager designed to create and manage `git
<http://git-scm.com/>`_ repositories in a remote server without the
need of administrator privileges. It was designed with the goal of
creating your own private repositories in a server to which you have
access and allows you to create connections to remote servers between
you and your collaborators via `ssh keys
<http://en.wikipedia.org/wiki/Secure_Shell#Key_management>`_.

Documentation
-------------

Installation and usage documentation is available in the ``docs/``
directory of the distribution and on `http://promus.readthedocs.org
<http://promus.readthedocs.org>`_.
